Discriminant Adaptive Nearest Neighbor Classification
dann(x, ..., k = 5, neighborhood_size = max(floor(nrow(x)/5), 50), epsilon = 1)An S3 class of type dann.
A matrix or a dataframe.
Additional parameters passed to methods.
The number of data points used for final classification.
The number of data points used to calculate between and within class covariance.
Diagonal elements of a diagonal matrix. 1 is the identity matrix.
This is an implementation of Hastie and Tibshirani's Discriminant Adaptive Nearest Neighbor Classification publication..